Properties Methods Events Direct Link

# Class Ext.calendar.BoxLayoutTemplate

Package: | Ext.calendar
Defined In: | BoxLayoutTemplate.js
Class: | BoxLayoutTemplate
Extends: | Object

This is the template used to render calendar views based on small day boxes within a non-scrolling container (currently the MonthView and the all-day headers for DayView and WeekView. This template is automatically bound to the underlying event store by the calendar components and expects records of type Ext.calendar.EventRecord.

## Public Properties

This class has no public properties.

## Public Methods

This class has no public methods.

## Public Events

This class has no public events.